@@ -1,8 +1,8 @@
 package XS::Log;
-#Build  MD5 : 9Scm+U7BCADWI+a+VZw8vg
-#Build Time : 2025-09-20 09:29:07
-our $VERSION = 1.08;
-our $BUILDDATE = "2025-09-20";  #Build Time: 09:29:07
+#Build  MD5 : xsJ8PB1dSdfaKfw4DbOY3w
+#Build Time : 2025-09-20 09:36:19
+our $VERSION = 1.09;
+our $BUILDDATE = "2025-09-20";  #Build Time: 09:36:19
 use strict;
 use warnings;
 use constant { 
@@ -42,7 +42,8 @@ XSLoader::load('XS::Log', $VERSION);
 sub printNote {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -53,7 +54,8 @@ sub printNote {
 sub printBug {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -64,7 +66,8 @@ sub printBug {
 sub printInf {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -75,7 +78,8 @@ sub printInf {
 sub printWarn {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -86,7 +90,8 @@ sub printWarn {
 sub printErr {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -97,7 +102,8 @@ sub printErr {
 sub printFail {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	my ($pkg, $file, $line);
+	my ($pkg,$file,$line);
+	$file = ""; $line = 0;
 	#判断是否调用caller会提速？
 	if(get_show_file_info())
 	{
@@ -108,7 +114,7 @@ sub printFail {
 sub printLog {
 	my ($fmt, @args) = @_;
 	my $msg = sprintf($fmt, @args);
-	xs_log_write(LOG_LEVEL_TEXT,undef,undef,$msg);
+	xs_log_write(LOG_LEVEL_TEXT,"",0,$msg);
 }
 1;
 
